@@ -24,8 +24,10 @@ class DKConnection():
         payload = {'parameters': overrides, "schedule" : "now"}
         return requests.put(url, headers=headers, data=json.dumps(payload))
 
-    def safeCreateOrder(self, kitchen, recipe, variation, overrides={}, wait_time=10, timeout=100000, test_level=""):
+    def safeCreateOrder(self, kitchen, recipe, variation, overrides={}, wait_time=10, timeout=50000, test_level=""):
         response = self.createOrder(kitchen, recipe, variation, overrides=overrides)
+        logger.debug(response.status_code)
+        logger.debug(response.text)
         if response.status_code != 200:
             logger.error("Error Starting Order %s %s %s." % (kitchen, recipe, variation))
             raise DKOrderException
@@ -55,6 +57,8 @@ class DKConnection():
         payload = {'order_id': order_id, 'summary': True, 'logs': True, 'timingresults': True,
                    'testresults': True, 'servingjson': True, "schedule": "now"}
         r = requests.post(url, headers=headers, data=json.dumps(payload))
+        logger.debug(r.status_code)
+        logger.debug(r.text)
         if "does not exist." in r.text:
             raise Exception("Order run id %s not found." % order_run_id )
         return DKOrder(json.loads(r.text))
