@@ -1,4 +1,4 @@
 from DKConnection import DKConnection
 
 conn = DKConnection("cloud.datakitchen.io", "armand+hm@datakitchen.io", "%Gun8D9M")
-results = conn.safeCreateOrder("hemonc_wns_prod", 'hemonc_rems' ,'wns-refresh-inrebic-reblozyl-calls')
+results = conn.safeCreateOrder("hemonc_sftp_automation", 'hemonc_sftp_automation' ,'test-variation')
